﻿var context;
var web;
var user;
var hostweburl;

// This function is run when the app is ready to start interacting with the host application
// It ensures the DOM is ready before adding click handlers to buttons
Office.initialize = function (reason) {
    $(document).ready(function () {

        // If setSelectedDataAsync method is supported by the host application
        // setDatabtn is hooked up to call the method else setDatabtn is removed
        if (Office.context.document.setSelectedDataAsync) {
            $('#SaveRef').click(function () { saveReferenceContent('#ContentTitle'); });
        }
        else {
            $('#SaveRef').remove();
        }

        context = SP.ClientContext.get_current();
        web = context.get_web();

        getUserName();

        retrieveListItems();
    });
};

// GET USERNAME START

// This function prepares, loads, and then executes a SharePoint query to get the current users information
function getUserName() {
    user = web.get_currentUser();
    context.load(user);
    context.executeQueryAsync(onGetUserNameSuccess, onGetUserNameFail);
}

// This function is executed if the above OM call is successful
// It replaces the contents of the 'welcomeMessage' element with the user name
function onGetUserNameSuccess() {
    $('#welcomeMessage').text('Hi ' + user.get_title() + ' welcome to the Document Builder App.');
}

// This function is executed if the above call fails
function onGetUserNameFail(sender, args) {
    $('#ActivityStatus').text('Failed to get user name. Error:' + args.get_message());
}

// GET USERNAME END


// GET ALL LIST ITEMS START

// This function calls into the references list in the SP app and gets its items for display
function retrieveListItems() {
    var clientContext = SP.ClientContext.get_current();
    var oList = clientContext.get_web().get_lists().getByTitle('References');

    var camlQuery = new SP.CamlQuery();
    camlQuery.set_viewXml(
        '<View><Query><Where><Geq><FieldRef Name=\'ID\'/>' +
        '<Value Type=\'Number\'>1</Value></Geq></Where></Query>' +
        '<RowLimit>10</RowLimit></View>'
    );
    this.collListItem = oList.getItems(camlQuery);

    clientContext.load(collListItem);
    clientContext.executeQueryAsync(
        Function.createDelegate(this, this.onRetrieveListItemsQuerySucceeded),
        Function.createDelegate(this, this.onRetrieveListItemsQueryFailed)
    );
}

// This function is executed if the above OM call is successful
// It replaces the RefContentItems div with a table of the results
function onRetrieveListItemsQuerySucceeded(sender, args) {
    var listItemInfo = '';
    var listItemEnumerator = collListItem.getEnumerator();
    
    var listItemInfo;

    while (listItemEnumerator.moveNext()) {
        var oListItem = listItemEnumerator.get_current();

        listItemInfo += "<tr><td><button class='btnInsertToDoc' id='btnInsertToDoc_" + oListItem.get_id() + "'>Insert</button>";
        listItemInfo += "</td><td>"
        listItemInfo += oListItem.get_item('Title');
        listItemInfo += "</td><tr>";
    }

    if (listItemInfo.length !== 0) {
        var completeTableHtml = "<table>" + listItemInfo + "</table>"; 
        $('#RefContentItems').html(listItemInfo.toString());
    }

    

    $('.btnInsertToDoc').bind('click', function () {
        var t = $(this);
        var itemId = $(this).attr('id');
        itemId = itemId.replace('btnInsertToDoc_', '');

        //Uncomment to see the debug of id collected
        //$('#ActivityStatus').text('Fetched item ID was ' + itemId);

        //Get the item and insert it
        retrieveListItemContent(itemId);
    });
}

// This function is executed if the above call fails
function onRetrieveListItemsQueryFailed(sender, args) {
    $('#ActivityStatus').text('Request failed. ' + args.get_message() +
        '\n' + args.get_stackTrace());
}

// GET ALL LIST ITEMS END


// GET LIST ITEM START

// This function calls into the references list in the SP app and gets its item for insertion
function retrieveListItemContent(itemID) {
    var clientContext = SP.ClientContext.get_current();
    var oList = clientContext.get_web().get_lists().getByTitle('References');

    var listItem = oList.getItemById(itemID);

    clientContext.load(listItem);
    clientContext.executeQueryAsync(
        Function.createDelegate(this, this.onGetListItemQuerySucceeded),
        Function.createDelegate(this, this.onGetListItemQueryFailed)
    );
}

// This function is executed if the above OM call is successful
// If adds the selected item content to the document at the cursor point
function onGetListItemQuerySucceeded() {
    Office.context.document.setSelectedDataAsync(oListItem.get_item('ReferenceContentColumn'), { coercionType: "ooxml" });
    $('#ActivityStatus').text('Content added to your document');
    retrieveListItems();
}

// This function is executed if the above call fails
function onGetListItemQueryFailed(sender, args) {
    $('#ActivityStatus').text('Request failed. ' + args.get_message() +
        '\n' + args.get_stackTrace());
}

// GET LIST ITEM END


// CREATE NEW CONTENT START

// Reads the data from current selection of the document and adds it to the references list
function saveReferenceContent(elementId) {
    //Using the OpenXml as this keeps the formatting correctly
    Office.context.document.getSelectedDataAsync(Office.CoercionType.Ooxml,
    function (result) {
        if (result.status === 'succeeded') {


            this.createReferenceListItem($(elementId).val(), result.value);
        }
    });
}

// This function adds the list item
function createReferenceListItem(contentTitle, documentContent) {
    var clientContext = SP.ClientContext.get_current();
    var oList = clientContext.get_web().get_lists().getByTitle('References');

    var itemCreateInfo = new SP.ListItemCreationInformation();
    this.oListItem = oList.addItem(itemCreateInfo);
    oListItem.set_item('Title', contentTitle);
    oListItem.set_item('ReferenceContentColumn', documentContent);
    oListItem.update();

    clientContext.load(oListItem);
    clientContext.executeQueryAsync(
        Function.createDelegate(this, this.onCreateReferenceListItemQuerySucceeded),
        Function.createDelegate(this, this.onCreateReferenceListItemQueryFailed)
    );
}

// This function refreshes the picker list
function onCreateReferenceListItemQuerySucceeded() {

    $('#ActivityStatus').text('Item created: ' + oListItem.get_id());
    retrieveListItems();
}

// This function is executed if the above call fails
function onCreateReferenceListItemQueryFailed(sender, args) {
    $('#ActivityStatus').text('Request failed. ' + args.get_message() +
        '\n' + args.get_stackTrace());
}

// CREATE NEW CONTENT END